summaryrefslogtreecommitdiffstats
path: root/vcs/subversion/kdevsvnd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/subversion/kdevsvnd.cpp')
-rw-r--r--vcs/subversion/kdevsvnd.cpp122
1 files changed, 61 insertions, 61 deletions
diff --git a/vcs/subversion/kdevsvnd.cpp b/vcs/subversion/kdevsvnd.cpp
index 9195c24c..7b4a42d3 100644
--- a/vcs/subversion/kdevsvnd.cpp
+++ b/vcs/subversion/kdevsvnd.cpp
@@ -25,8 +25,8 @@
#include <kfiledialog.h>
#include <ktextedit.h>
#include <kpassdlg.h>
-#include <qdir.h>
-#include <qfile.h>
+#include <tqdir.h>
+#include <tqfile.h>
#include "config.h"
@@ -36,71 +36,71 @@
#include "commitdlg.h"
extern "C" {
- KDE_EXPORT KDEDModule *create_kdevsvnd(const QCString &name) {
+ KDE_EXPORT KDEDModule *create_kdevsvnd(const TQCString &name) {
return new KDevSvnd(name);
}
}
-KDevSvnd::KDevSvnd(const QCString &name)
+KDevSvnd::KDevSvnd(const TQCString &name)
: KDEDModule(name) {
}
KDevSvnd::~KDevSvnd()
{}
-QString KDevSvnd::commitDialog(QString modifiedFiles) {
+TQString KDevSvnd::commitDialog(TQString modifiedFiles) {
CommitDlg commitDlg;
commitDlg.setCaption(i18n("Enter Commit Log Message:"));
commitDlg.listMessage->setText( modifiedFiles );
int result = commitDlg.exec();
- if ( result == QDialog::Accepted ) {
+ if ( result == TQDialog::Accepted ) {
return commitDlg.textMessage->text();
} else
- return QString::null;
+ return TQString::null;
}
-int KDevSvnd::sslServerTrustPrompt( QString errmsg, QString hostname, QString fingerPrint, QString validfrom, QString validuntil, QString issuerName, QString ascii_cert )
+int KDevSvnd::sslServerTrustPrompt( TQString errmsg, TQString hostname, TQString fingerPrint, TQString validfrom, TQString validuntil, TQString issuerName, TQString ascii_cert )
{
SvnSSLTrustPrompt dlg;
dlg.setupCertInfo( hostname, fingerPrint, validfrom, validuntil, issuerName, ascii_cert );
dlg.setupFailedReasonMsg( errmsg );
int result = dlg.exec();
- if ( result == QDialog::Accepted ){
+ if ( result == TQDialog::Accepted ){
return dlg.code();
} else{
return -1;
}
}
-QString KDevSvnd::sslCertFile()
+TQString KDevSvnd::sslCertFile()
{
- QString fileName = KFileDialog::getOpenFileName(QString::null,QString::null,0, i18n("Open SSL certificate file"));
+ TQString fileName = KFileDialog::getOpenFileName(TQString::null,TQString::null,0, i18n("Open SSL certificate file"));
return fileName;
}
-QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
+TQCString KDevSvnd::sslPasswdDlg(TQString promptMsg)
{
- QCString passwd;
+ TQCString passwd;
int ret = KPasswordDialog::getPassword( passwd,promptMsg );
if( ret == KPasswordDialog::Accepted ){
- QCString retstr;
+ TQCString retstr;
retstr.setNum(1);
return retstr + passwd;
} else{
- QCString nullstr;
+ TQCString nullstr;
nullstr.setNum(-1);
return nullstr;
}
}
// void KDevSvnd::registerMe(const QCString &app)
// {
// insert(app, "test", new TestObject(app));
// // When 'app' unregisters with DCOP, the TestObject will get deleted.
// }
// bool KSvnd::AreAnyFilesInSvn( const KURL::List& wclist ) {
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// kdDebug( 9036 ) << "Checking file " << ( *it ) << endl;
-// QDir bdir ( ( *it ).path() );
-// if ( bdir.exists() && QFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
+// TQDir bdir ( ( *it ).path() );
+// if ( bdir.exists() && TQFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
// return true;
// } else if ( !bdir.exists() ) {
// if ( isFileInSvnEntries( ( *it ).fileName(), ( *it ).directory() + "/.svn/entries" ) || isFileInExternals ( ( *it ).fileName(), ( *it ).directory()+"/.svn/dir-props" ) )
@@ -111,10 +111,10 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// }
//
// bool KSvnd::AreAnyFilesNotInSvn( const KURL::List& wclist ) {
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// kdDebug( 9036 ) << "Checking file " << ( *it ) << endl;
-// QDir bdir ( ( *it ).path() );
-// if ( bdir.exists() && !QFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
+// TQDir bdir ( ( *it ).path() );
+// if ( bdir.exists() && !TQFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
// return true;
// } else if ( !bdir.exists() ) {
// if ( !isFileInSvnEntries( ( *it ).fileName(),( *it ).directory() + "/.svn/entries" ) && !isFileInExternals ( ( *it ).fileName(), ( *it ).directory()+"/.svn/dir-props" ) )
@@ -125,10 +125,10 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// }
//
// bool KSvnd::AreAllFilesInSvn( const KURL::List& wclist ) {
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// kdDebug( 9036 ) << "Checking file " << ( *it ) << endl;
-// QDir bdir ( ( *it ).path() );
-// if ( bdir.exists() && !QFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
+// TQDir bdir ( ( *it ).path() );
+// if ( bdir.exists() && !TQFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
// return false;
// } else if ( !bdir.exists() ) {
// if ( !isFileInSvnEntries( ( *it ).fileName(),( *it ).directory() + "/.svn/entries" ) && !isFileInExternals ( ( *it ).fileName(), ( *it ).directory()+"/.svn/dir-props" ) )
@@ -139,10 +139,10 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// }
//
// bool KSvnd::AreAllFilesNotInSvn( const KURL::List& wclist ) {
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// kdDebug( 9036 ) << "Checking file " << ( *it ) << endl;
-// QDir bdir ( ( *it ).path() );
-// if ( bdir.exists() && QFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
+// TQDir bdir ( ( *it ).path() );
+// if ( bdir.exists() && TQFile::exists( ( *it ).path() + "/.svn/entries" ) ) {
// return false;
// } else if ( !bdir.exists() ) {
// if ( isFileInSvnEntries( ( *it ).fileName(),( *it ).directory() + "/.svn/entries" ) || isFileInExternals ( ( *it ).fileName(), ( *it ).directory()+"/.svn/dir-props" ) )
@@ -152,11 +152,11 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// return true;
// }
//
-// bool KSvnd::isFileInSvnEntries ( const QString filename, const QString entfile ) {
-// QFile file( entfile );
+// bool KSvnd::isFileInSvnEntries ( const TQString filename, const TQString entfile ) {
+// TQFile file( entfile );
// if ( file.open( IO_ReadOnly ) ) {
-// QTextStream stream( &file );
-// QString line;
+// TQTextStream stream( &file );
+// TQString line;
// while ( !stream.atEnd() ) {
// line = stream.readLine().simplifyWhiteSpace();
// if ( line == "name=\""+ filename + "\"" ) {
@@ -169,11 +169,11 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// return false;
// }
//
-// bool KSvnd::isFileInExternals ( const QString filename, const QString propfile ) {
-// QFile file( propfile );
+// bool KSvnd::isFileInExternals ( const TQString filename, const TQString propfile ) {
+// TQFile file( propfile );
// if ( file.open( IO_ReadOnly ) ) {
-// QTextStream stream( &file );
-// QStringList line;
+// TQTextStream stream( &file );
+// TQStringList line;
// while ( !stream.atEnd() )
// line << stream.readLine().simplifyWhiteSpace();
// for ( uint i = 0 ; i < line.count(); i++ ) {
@@ -202,38 +202,38 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
//
// bool KSvnd::anyNotValidWorkingCopy( const KURL::List& wclist ) {
// bool result = true; //one negative match is enough
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// //exception for .svn dirs
// if ( ( *it ).path(-1).endsWith( "/.svn" ) )
// return true;
// //if is a directory check whether it contains a .svn/entries file
-// QDir dir( ( *it ).path() );
+// TQDir dir( ( *it ).path() );
// if ( dir.exists() ) { //it's a dir
-// if ( !QFile::exists( ( *it ).path() + "/.svn/entries" ) )
+// if ( !TQFile::exists( ( *it ).path() + "/.svn/entries" ) )
// result = false;
// }
//
// //else check if ./.svn/entries exists
-// if ( !QFile::exists( ( *it ).directory() + "/.svn/entries" ) )
+// if ( !TQFile::exists( ( *it ).directory() + "/.svn/entries" ) )
// result = false;
// }
// return result;
// }
//
// bool KSvnd::anyValidWorkingCopy( const KURL::List& wclist ) {
-// for ( QValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = wclist.begin(); it != wclist.end() ; ++it ) {
// //skip .svn dirs
// if ( ( *it ).path(-1).endsWith( "/.svn" ) )
// continue;
// //if is a directory check whether it contains a .svn/entries file
-// QDir dir( ( *it ).path() );
+// TQDir dir( ( *it ).path() );
// if ( dir.exists() ) { //it's a dir
-// if ( QFile::exists( ( *it ).path() + "/.svn/entries" ) )
+// if ( TQFile::exists( ( *it ).path() + "/.svn/entries" ) )
// return true;
// }
//
// //else check if ./.svn/entries exists
-// if ( QFile::exists( ( *it ).directory() + "/.svn/entries" ) )
+// if ( TQFile::exists( ( *it ).directory() + "/.svn/entries" ) )
// return true;
// }
// return false;
@@ -242,7 +242,7 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// int KSvnd::getStatus( const KURL::List& list ) {
// int result = 0;
// uint files = 0, folders = 0, parentsentries = 0, parentshavesvn = 0, subdirhavesvn = 0, external = 0;
-// for ( QValueListConstIterator<KURL> it = list.begin(); it != list.end() ; ++it ) {
+// for ( TQValueListConstIterator<KURL> it = list.begin(); it != list.end() ; ++it ) {
// if ( isFolder ( ( *it ) ) ) {
// folders++;
// } else {
@@ -251,13 +251,13 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// if ( isFileInSvnEntries ( (*it).filename(),( *it ).directory() + "/.svn/entries" ) ) { // normal subdir known in the working copy
// parentsentries++;
// } else if ( isFolder( *it ) ) { // other subfolders (either another module checkouted or an external, or something not known at all)
-// if ( QFile::exists( ( *it ).path() + "/.svn/entries" ) )
+// if ( TQFile::exists( ( *it ).path() + "/.svn/entries" ) )
// subdirhavesvn++;
// if ( isFileInExternals( (*it).filename(), ( *it ).directory() + "/.svn/dir-props" ) ) {
// external++;
// }
// }
-// if ( ( isFolder( ( *it ) ) && QFile::exists( ( *it ).directory() + "../.svn/entries" ) ) || QFile::exists( ( *it ).directory() + "/.svn/entries" ) ) //parent has a .svn ?
+// if ( ( isFolder( ( *it ) ) && TQFile::exists( ( *it ).directory() + "../.svn/entries" ) ) || TQFile::exists( ( *it ).directory() + "/.svn/entries" ) ) //parent has a .svn ?
// parentshavesvn++;
// }
// if ( files > 0 )
@@ -293,12 +293,12 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// }
//
// bool KSvnd::isFolder( const KURL& url ) {
-// QDir d( url.path() );
+// TQDir d( url.path() );
// return d.exists();
// }
//
-// QStringList KSvnd::getActionMenu ( const KURL::List &list ) {
-// QStringList result;
+// TQStringList KSvnd::getActionMenu ( const KURL::List &list ) {
+// TQStringList result;
// int listStatus = getStatus( list );
//
// if ( !(listStatus & SomeAreInParentsEntries) &&
@@ -347,8 +347,8 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// return result;
// }
//
-// QStringList KSvnd::getTopLevelActionMenu ( const KURL::List &list ) {
-// QStringList result;
+// TQStringList KSvnd::getTopLevelActionMenu ( const KURL::List &list ) {
+// TQStringList result;
// int listStatus = getStatus( list );
//
//
@@ -364,28 +364,28 @@ QCString KDevSvnd::sslPasswdDlg(QString promptMsg)
// }
//
// #if 0
-// void KSvnd::notify(const QString& path, int action, int kind, const QString& mime_type, int content_state, int prop_state, long int revision, const QString& userstring) {
+// void KSvnd::notify(const TQString& path, int action, int kind, const TQString& mime_type, int content_state, int prop_state, long int revision, const TQString& userstring) {
// kdDebug(9036) << "KDED/Subversion : notify " << path << " action : " << action << " mime_type : " << mime_type << " content_state : " << content_state << " prop_state : " << prop_state << " revision : " << revision << " userstring : " << userstring << endl;
-// QByteArray params;
+// TQByteArray params;
//
-// QDataStream stream(params, IO_WriteOnly);
+// TQDataStream stream(params, IO_WriteOnly);
// stream << path << action << kind << mime_type << content_state << prop_state << revision << userstring;
//
-// emitDCOPSignal( "subversionNotify(QString,int,int,QString,int,int,long int,QString)", params );
+// emitDCOPSignal( "subversionNotify(TQString,int,int,TQString,int,int,long int,TQString)", params );
// }
//
-// void KSvnd::status(const QString& path, int text_status, int prop_status, int repos_text_status, int repos_prop_status, long int rev ) {
+// void KSvnd::status(const TQString& path, int text_status, int prop_status, int repos_text_status, int repos_prop_status, long int rev ) {
// kdDebug(9036) << "KDED/Subversion : status " << path << " " << text_status << " " << prop_status << " "
// << repos_text_status << " " << repos_prop_status << " " << rev << endl;
-// QByteArray params;
+// TQByteArray params;
//
-// QDataStream stream(params, IO_WriteOnly);
+// TQDataStream stream(params, IO_WriteOnly);
// stream << path << text_status << prop_status << repos_text_status << repos_prop_status << rev;
//
-// emitDCOPSignal( "subversionStatus(QString,int,int,int,int,long int)", params );
+// emitDCOPSignal( "subversionStatus(TQString,int,int,int,int,long int)", params );
// }
//
-// void KSvnd::popupMessage( const QString& message ) {
+// void KSvnd::popupMessage( const TQString& message ) {
// kdDebug(9036) << "KDED/Subversion : popupMessage" << message << endl;
// KMessageBox::information(0, message, i18n( "Subversion" ) );
// }
@@ -36,71 +36,71 @@
}
}
-// void KDevSvnd::registerMe(const QCString &app)
+// void KDevSvnd::registerMe(const TQCString &app)
// {
// insert(app, "test", new TestObject(app));